aboutsummaryrefslogtreecommitdiffstats
path: root/tests/auto/qtquick1/qdeclarativetext/tst_qdeclarativetext.cpp
diff options
context:
space:
mode:
authorPekka Vuorela <pekka.ta.vuorela@nokia.com>2012-01-05 16:33:56 +0200
committerQt by Nokia <qt-info@nokia.com>2012-01-12 16:21:35 +0100
commit39f9b5def185337b2087cadeb3e137dfbeb85fa4 (patch)
treebb401cd8846ad29ecfe0b5f4c4bcfe12c101c3c0 /tests/auto/qtquick1/qdeclarativetext/tst_qdeclarativetext.cpp
parentbe1534e5df82561842d1847f90f1cab9462e10ef (diff)
Adapt to QInputPanel::inputDirection() API
Information moved from QGuiApplication into QInputPanel. Change-Id: Idd80609f4b67bffae7222a1fa27918724ebf60f6 Reviewed-by: Joona Petrell <joona.t.petrell@nokia.com>
Diffstat (limited to 'tests/auto/qtquick1/qdeclarativetext/tst_qdeclarativetext.cpp')
-rw-r--r--tests/auto/qtquick1/qdeclarativetext/tst_qdeclarativetext.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/auto/qtquick1/qdeclarativetext/tst_qdeclarativetext.cpp b/tests/auto/qtquick1/qdeclarativetext/tst_qdeclarativetext.cpp
index 65c1d4e5cb..fa49cd8595 100644
--- a/tests/auto/qtquick1/qdeclarativetext/tst_qdeclarativetext.cpp
+++ b/tests/auto/qtquick1/qdeclarativetext/tst_qdeclarativetext.cpp
@@ -636,9 +636,9 @@ void tst_qdeclarativetext::horizontalAlignment_RightToLeft()
#ifndef Q_OS_MAC // QTBUG-18040
// empty text with implicit alignment follows the system locale-based
// keyboard input direction from QApplication::keyboardInputDirection
text->setText("");
- QCOMPARE(text->hAlign(), QApplication::keyboardInputDirection() == Qt::LeftToRight ?
+ QCOMPARE(text->hAlign(), qApp->inputPanel()->inputDirection() == Qt::LeftToRight ?
QDeclarative1Text::AlignLeft : QDeclarative1Text::AlignRight);
text->setHAlign(QDeclarative1Text::AlignRight);
QCOMPARE(text->hAlign(), QDeclarative1Text::AlignRight);
@@ -652,7 +652,7 @@ void tst_qdeclarativetext::horizontalAlignment_RightToLeft()
QDeclarativeComponent textComponent(&engine);
textComponent.setData(componentStr.toLatin1(), QUrl::fromLocalFile(""));
QDeclarative1Text *textObject = qobject_cast<QDeclarative1Text*>(textComponent.create());
- QCOMPARE(textObject->hAlign(), QApplication::keyboardInputDirection() == Qt::LeftToRight ?
+ QCOMPARE(textObject->hAlign(), qApp->inputPanel()->inputDirection() == Qt::LeftToRight ?
QDeclarative1Text::AlignLeft : QDeclarative1Text::AlignRight);
delete textObject;
#endif
@@ -636,9 +636,9 @@ void tst_qdeclarativetext::horizontalAlignment_RightToLeft()
#ifndef Q_OS_MAC // QTBUG-18040
// empty text with implicit alignment follows the system locale-based
- // keyboard input direction from QApplication::keyboardInputDirection
+ // keyboard input direction from QInputpanel::inputDirection
text->setText("");